<!-- Copyright 2024 Remy Blank <remy@c-space.org> -->
<!-- SPDX-License-Identifier: MIT -->

# t-doc - Common

[![Publish](https://github.com/t-doc-org/common/actions/workflows/publish.yml/badge.svg)](https://github.com/t-doc-org/common/actions/workflows/publish.yml)
[![Package](https://github.com/t-doc-org/common/actions/workflows/package.yml/badge.svg)](https://github.com/t-doc-org/common/actions/workflows/package.yml)
[![PyPI](https://img.shields.io/pypi/v/t-doc-common.svg?color=blue)](https://pypi.org/project/t-doc-common/)

This package contains the common functionality for documents based on t-doc. See
the [documentation](https://common.t-doc.org/) for more information.

This software is distributed under the [MIT](LICENSE.txt) license.
